
//  ViewController.swift
//  CrashTest
//
//  Created by Oleksandr Kirichenko on 2/15/17.
//
//

import UIKit

class ViewController: UIViewController {
    @IBOutlet weak var toBottomConstraint: NSLayoutConstraint!
    let formatter: DateFormatter = {
        let formatter = DateFormatter()
        formatter.dateFormat = "yyyy MM dd"
        formatter.timeZone = Calendar.current.timeZone
        formatter.locale = Calendar.current.locale
        return formatter
    }()
    
    var weekMode = false {
        didSet {
            if weekMode {
                toBottomConstraint.constant = UIScreen.main.bounds.height * 0.8
                calendarView.scrollDirection = .horizontal
                calendarView.itemSize = nil
                calendarView.scrollingMode = .stopAtEachSection
            } else {
                toBottomConstraint.constant = 0
                calendarView.scrollDirection = .vertical
                calendarView.itemSize = floor(UIScreen.main.bounds.height / 12.5)
                calendarView.scrollingMode = .nonStopToCell(withResistance: 0.75)
            }
        }
    }
    
    @IBOutlet weak var calendarView: JTAppleCalendarView! {
        didSet {
            calendarView.delegate = self
            calendarView.dataSource = self
            calendarView.registerCellViewXib(file: "CellView")
        }
    }

    let dateFormatter = DateFormatter()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        weekMode = false
        dateFormatter.dateFormat = "MMM"
    }
    
}

extension ViewController: JTAppleCalendarViewDataSource {
    func configureCalendar(_ calendar: JTAppleCalendarView) -> ConfigurationParameters {
        let startDate = formatter.date(from: "2017 01 01")!
        let endDate = formatter.date(from: "2018 01 01")!
        
        let parameters = ConfigurationParameters(startDate: startDate,
                                                 endDate: endDate,
                                                 numberOfRows: weekMode ? 1 : 6,
                                                 generateInDates: weekMode ? .forFirstMonthOnly : .forAllMonths,
                                                 generateOutDates: .off,
                                                 firstDayOfWeek: .monday,
                                                 hasStrictBoundaries: false )
        
        return parameters
    }
}

extension ViewController: JTAppleCalendarViewDelegate {
    func calendar(_ calendar: JTAppleCalendarView, didSelectDate date: Date, cell: JTAppleDayCellView?, cellState: CellState) {
        weekMode = !weekMode

        calendarView.reloadData {
            self.calendarView.scrollToDate(date, triggerScrollToDateDelegate: false, animateScroll: false)
        }
    }
    
    func calendar(_ calendar: JTAppleCalendarView, willDisplayCell cell: JTAppleDayCellView, date: Date, cellState: CellState) {
        guard let myCustomCell = cell as? CellView else { return }
        
        myCustomCell.dayLabel.text = cellState.text
        if cellState.text == "1" {
            myCustomCell.monthLabel.text = dateFormatter.string(from: date)
        } else {
            myCustomCell.monthLabel.text = ""
        }
            
        switch cellState.dateBelongsTo {
        case .thisMonth:
            myCustomCell.backgroundColor = nil
        default:
            myCustomCell.backgroundColor = UIColor.yellow
        }
    }
}
